import { useAjax } from "@/Hook/useAjax"
import useApi from "@/Hook/useApi"
import { longBookInfoList, shortBookInfoList } from "@/services/miniApp/bookManage"
import { useModel } from "@umijs/max"
import { Button, Divider, Pagination, Select, Space, Tag } from "antd"
import { useCallback, useEffect, useMemo, useRef, useState } from "react"

const BookSelect = (props: { value?: any, onChange?: (value: any) => void }) => {
    let { value, onChange } = props
    let { initialState } = useModel("@@initialState")
    let { state } = useModel("appPageConifg")
    let publicData = useMemo(() => {
        return {
            appId: initialState?.selectApp?.id || "",
            distributorId: initialState?.currentUser?.distributorId,
            appType: initialState?.selectApp?.appType || "",
            workDirection: state.tabs
        }
    }, [initialState?.selectApp, initialState?.currentUser?.distributorId, state.index])
    let apiobj = useApi(initialState?.selectApp?.appCategory || 1)
    let getList = useAjax((params) => apiobj.getBookPageList(params))
    let api = useMemo(() => {
        return getList
    }, [initialState?.selectApp])
    let timeOut = useRef<any>()
    let [params, setParmas] = useState({
        pageNum: 1,
        pageSize: 20,
        bookName: ""
    })
    const [data, setData] = useState<{ records: any[], total: number }>({ records: [], total: 0 })
    // 防抖
    const debounce = useCallback((func: any, wait: number) => {
        if (timeOut.current) {
            clearTimeout(timeOut.current);
        }
        timeOut.current = setTimeout(() => { func() }, wait);
    }, [])
    useEffect(() => {
        if (value && data?.records?.length === 0) {
            api.run({ pageNum: 1, pageSize: 20, bookId: value, ...publicData }).then(res => {
                if (res?.data?.total > 0) {
                    setData({ records: res.data.records, total: res.data.total })
                } else {
                    setData({ records: [], total: 0 })
                }
            })
        }
    }, [])
    // 使用自定义防抖函数
    useEffect(() => {
        if (params.bookName) {
            api.run({ ...params, ...publicData }).then(res => {
                if (res?.data?.total > 0) {
                    setData({ records: res.data.records, total: res.data.total })
                } else {
                    setData({ records: [], total: 0 })
                }
            })
        }
    }, [params, api])
    return <div style={{ display: 'flex' }}>
        <Select
            placeholder="输入书籍名称搜索"
            showSearch
            filterOption={false}
            onSearch={(value) => {
                debounce(() => { setParmas({ ...params, bookName: value }) }, 500)
            }}
            onChange={(value, option) => {
                onChange?.(initialState?.selectApp?.appCategory === 1 ? option?.longBookInfo : option?.shortBookInfoVO)
            }}
            value={value?.id || value}
            dropdownRender={(menu) => {
                return <>
                    {menu}
                    <Divider style={{ margin: '8px 0' }} />
                    <Pagination
                        total={data?.total}
                        pageSize={params.pageSize}
                        hideOnSinglePage
                        showTotal={(total) => <Tag>{total}条数据</Tag>}
                        size='small'
                        showQuickJumper={false}
                        showSizeChanger={false}
                        onChange={(page, pageSize: number) => {
                            setParmas({ ...params, pageNum: page, pageSize })
                        }}
                    />
                </>
            }}
            options={data?.records?.map(item => ({ label: initialState?.selectApp?.appCategory === 1 ? item.longBookInfo.bookName : item.shortBookInfoVO.bookName, value: item.bookId, ...item }))}
        />
    </div>

}
export default BookSelect