import { ProFormColumnsType } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";

function formConfig(): ProFormColumnsType<{
}>[] {
    let { getEnum } = useModel("global")
    return [
        {
            valueType: 'digit',
            dataIndex: "regPayIntervalTime",
            title: "注册充值回传的最大间隔时间",
            tooltip: "（超时不回传）",
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                placeholder: '请输入数字',
                style: { width: "70%" },
                addonAfter: "分钟"
            },
        },
        {
            valueType: 'radioButton',
            dataIndex: "vipOrderBackType",
            title: "VIP回传策略",
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            valueEnum: getEnum("VIP_CALLBACK", "map")
        },
        {
            valueType: 'radioButton',
            dataIndex: "backUnit",
            title: "回传类型",
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            valueEnum: getEnum("CALLBACK_TYPE", "map")
        },
        {
            valueType: 'dependency',
            name: ["backUnit"],
            columns({ backUnit }) {
                console.log("backUnit", backUnit)
                return [
                    {
                        valueType: 'divider',
                        fieldProps: {
                            children: backUnit === 1 ? "首单" : "首日",
                            orientation: "left"
                        }
                    },
                    {
                        dataIndex: 'firstBackRate',
                        valueType: 'formList',
                        fieldProps: {
                            creatorButtonProps: {
                                creatorButtonText: "添加一个档位配置",
                            },
                        },
                        colProps: {
                            span: 24
                        },
                        columns: [
                            {
                                valueType: 'group',
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        dataIndex: 'minAmount',
                                        valueType: 'digit',
                                        title: "最小金额",
                                        tooltip: "最小金额（大于等于）",
                                        fieldProps: {
                                            placeholder: "最小金额",
                                            style: { width: "100%" },
                                        },
                                        colProps: { span: 5 },
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                    },
                                    {
                                        dataIndex: 'maxAmount',
                                        valueType: 'digit',
                                        title: "最大金额",
                                        tooltip: "最大金额（小于）",
                                        colProps: { span: 5 },
                                        fieldProps: {
                                            placeholder: "最大金额",
                                            style: { width: "100%" },
                                        },
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                    },
                                    {
                                        dataIndex: 'type',
                                        valueType: 'radioButton',
                                        title: "回传方式",
                                        colProps: { span: 7 },
                                        initialValue: "2",
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                        valueEnum: {1:{text:"比例"},2:{text:"概率"}},
                                    },
                                    {
                                        valueType:"dependency",
                                        name:["type"],
                                        columns(values) {
                                            console.log(values)
                                            let {type} = values
                                            return []
                                        },
                                    }
                                ]
                            }
                        ]
                    },
                ]
            },
        },


        // {
        //     title: '付费方式',
        //     dataIndex: 'paymentType',
        //     valueType: 'radio',
        //     fieldProps: {
        //         onChange: (e) => {
        //             let value = e.target.value
        //             paymentType[1](value)
        //         }
        //     },
        //     formItemProps: {
        //         style: { marginBottom: 10 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     valueEnum: () => {
        //         let arr = enumList?.PAYMENT_TYPE?.values
        //         return new Map(arr?.map(({ value, description }: any) => [value, description]))
        //     }
        // },
        // {
        //     title: '收费类型',
        //     dataIndex: 'paymentOption',
        //     valueType: 'radio',
        //     formItemProps: {
        //         style: { marginBottom: 10 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     hideInForm: paymentType[0] != 2,
        //     valueEnum: () => {
        //         let arr = enumList?.PAYMENT_OPTION?.values
        //         return new Map(arr?.map(({ value, description }: any) => [value, description]))
        //     }
        // },
        // {
        //     title: '收费货币',
        //     dataIndex: 'paymentCategory',
        //     valueType: 'radio',
        //     fieldProps: {
        //         onChange: (e) => {
        //             let value = e.target.value
        //             paymentCategory[1](value)
        //         },
        //     },
        //     formItemProps: {
        //         style: { marginBottom: 10 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     hideInForm: paymentType[0] == 0,
        //     valueEnum: () => {
        //         let arr = [{ value: 0, description: "现金" }, { value: 1, description: "书币" }]
        //         return new Map(arr?.map(({ value, description }: any) => [value, description]))
        //     }
        // },
        // {//单本
        //     title: '付费起始段落',
        //     dataIndex: 'beginPayParagraphNo',
        //     valueType: 'select',
        //     fieldProps: {
        //         showSearch: true, placeholder: '请选择开始收费段落'
        //     },
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     hideInForm: paymentType[0] === 0 || isGlobalConfig,//单本书
        //     valueEnum: () => {
        //         return new Map(paragraphList?.map(item => [item.paragraphNo, item.content]))
        //     }
        // },
        // {//全局
        //     title: '付费起始段落',
        //     dataIndex: 'beginPayNo',
        //     valueType: 'digit',
        //     fieldProps: {
        //         placeholder: '请输入收费段落'
        //     },
        //     width: 200,
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     hideInForm: paymentType[0] != 2 || !isGlobalConfig,//单本书
        // },
        // {
        //     title: 'VIP阅读',
        //     dataIndex: 'vipFree',
        //     valueType: 'segmented',
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        //     hideInForm: paymentType[0] == 0 || isGlobalConfig,
        //     valueEnum: () => {
        //         let arr = enumList?.VIP_FREE?.values
        //         return new Map(arr?.map(({ value, description }: any) => [value, description]))
        //     }
        // },
        // {
        //     title: '收费金额',
        //     dataIndex: 'paymentAmount',
        //     valueType: 'money',
        //     hideInForm: paymentType[0] === 0 || paymentCategory[0] == 1,
        //     fieldProps: {
        //         addonAfter: "元",
        //     },
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        // },
        // {
        //     title: '收费书币',
        //     dataIndex: 'paymentCoin',
        //     valueType: 'digit',
        //     hideInForm: paymentType[0] === 0 || paymentCategory[0] == 0,
        //     fieldProps: {
        //         addonAfter: "书币"
        //     },
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //         rules: [
        //             {
        //                 required: true,
        //                 message: '此项为必填项',
        //             },
        //         ],
        //     },
        // },
        // {
        //     title: '备注',
        //     dataIndex: 'remark',
        //     valueType: 'textarea',
        //     hideInForm: isGlobalConfig,
        //     formItemProps: {
        //         style: { marginBottom: 15 },
        //     },
        // }
    ]
}

export default formConfig