import { ActionType, PageContainer, ProTable } from "@ant-design/pro-components"
import { columns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { useModel } from "@umijs/max"
import { configUser, getAllAvailableKfs, getAllBindKfs, revoke } from "@/services/miniApp/entWeChat"
import { Button, message, Modal, Space, Tag } from "antd"
import { PlusOutlined } from "@ant-design/icons"
import { useRef, useState } from "react"

const Page: React.FC = () => {
    let { initialState } = useModel("@@initialState")
    let [open, setOpen] = useState(false)
    const actionRef = useRef<ActionType>();
    const [editSelectedRow, setEditSelectedRow] = useState<any[]>([]); //选择
    let getList = useAjax((params) => getAllBindKfs(params), { type: 'table' })//已授权列表
    let getNoAuthList = useAjax((params) => getAllAvailableKfs(params), { type: 'table' })//未授权列表
    let ConfigUser = useAjax((params) => configUser(params))//批量授权
    let Revoke = useAjax((params) => revoke(params))//取消授权
    let publicData = {
        appId: initialState?.selectApp?.id || "",
        appType: initialState?.selectApp?.appType || ""
    }
    // 批量授权
    const auth = () => {
        if (editSelectedRow.length > 0) {
            let corpUserList = editSelectedRow?.map(item => ({ corpId: item.corpId, corpUserId: item.corpUserId }))
            ConfigUser.run({
                ...publicData,
                corpUserList
            }).then(res => {
                if (res.code === 200) {
                    setOpen(false)
                    setEditSelectedRow([])
                    message.success("授权成功！")
                    actionRef?.current?.reload()
                }
            })
        }
    }
    // 取消授权
    const offAuth = (user: { corpId: any, corpUserId: any }) => {
        let corpUserList: any = []
        if (user) {
            corpUserList = [{ corpId: user.corpId, corpUserId: user.corpUserId }]
        }
        if (corpUserList.length > 0) {
            Revoke.run({ ...publicData, corpUserList }).then(res => {
                if (res.code === 200) {
                    message.success("取消授权成功！")
                    actionRef?.current?.reload()
                }
            })
        }
    }
    return <PageContainer
        title={false}
    >
        <ProTable<any, any>
            actionRef={actionRef}
            scroll={{ x: true }}
            toolBarRender={() => [
                <Button type="primary" onClick={() => { setOpen(true) }} ><PlusOutlined />添加授权</Button>,
            ]}
            params={publicData}
            headerTitle={"已授权客服号列表"}
            rowKey={(r) => r.corpUserId}
            search={{labelWidth:0}}
            request={async (params) => {
                return await getList.run(params)
            }}
            columns={columns(true,offAuth)}
        // bordered
        />
        <Modal
            title="添加客服号"
            open={open}
            onCancel={() => { setOpen(false) }}
            onOk={auth}
            width={"40%"}
            loading={ConfigUser?.loading}
            destroyOnClose
        >
            <ProTable<any, any>
                scroll={{ x: true, y: 600 }}
                params={{
                    appId: initialState?.selectApp?.id || "",
                    appType: initialState?.selectApp?.appType || ""
                }}
                //多选
                rowSelection={{
                    selectedRowKeys: editSelectedRow?.map((item: { corpUserId: any }) => item.corpUserId),
                    onSelect: (record, selected) => {
                        if (selected) {
                            setEditSelectedRow([...editSelectedRow, record]);
                        } else {
                            setEditSelectedRow(
                                editSelectedRow?.filter((item: { corpUserId: any }) => item.corpUserId !== record.corpUserId),
                            );
                        }
                    },
                    onSelectAll: (selected, rows, changeRows) => {
                        if (selected) {
                            setEditSelectedRow([...editSelectedRow, ...changeRows]);
                        } else {
                            let newArr = editSelectedRow?.filter((item: { corpUserId: any }) =>
                                changeRows.every((i) => i?.corpUserId !== item?.corpUserId),
                            );
                            setEditSelectedRow(newArr);
                        }
                    },
                }}
                // 添加取消选择按钮
                tableAlertOptionRender={() => {
                    return (
                        <Button type="link" onClick={() => {
                            setEditSelectedRow([])
                        }}>
                            取消选择
                        </Button>
                    );
                }}
                //多选展示栏
                tableAlertRender={({ selectedRowKeys, selectedRows }) => {
                    return (
                        <Space size={24}>
                            <span style={{ width: 90, display: 'inline-block' }}>
                                已选 {selectedRowKeys.length} 人
                            </span>
                            <span style={{ color: 'red' }}>
                                {selectedRows
                                    ?.map((item: { corpName: string, name: string, corpUserId: any }) => <Tag
                                        closable
                                        key={item?.corpUserId}
                                        onClose={() => {
                                            let newArr = selectedRows?.filter((i) => i?.corpUserId != item?.corpUserId)
                                            setEditSelectedRow(newArr)
                                        }}>{item?.corpName}-{item?.name}</Tag>)
                                }
                            </span>
                        </Space>
                    );
                }}
                toolBarRender={false}
                // headerTitle={false}
                rowKey={(r) => r.corpUserId}
                search={{
                    labelWidth: 0,
                }}
                request={async (params) => {
                    return await getNoAuthList.run(params)
                }}
                columns={columns()}
            // bordered
            />
        </Modal>
    </PageContainer>

}
export default Page